@@ -155,7 +155,8 @@ class ServiceOperator:
             database_name=database_name,
             schema_name=schema_name,
         )
-        if pc.PlatformCapabilities.get_instance().is_inlined_deployment_spec_enabled():
+        self._use_inlined_deployment_spec = pc.PlatformCapabilities.get_instance().is_inlined_deployment_spec_enabled()
+        if self._use_inlined_deployment_spec:
             self._workspace = None
             self._model_deployment_spec = model_deployment_spec.ModelDeploymentSpec()
         else:
@@ -264,7 +265,14 @@ class ServiceOperator:
             self._model_deployment_spec.add_hf_logger_spec(
                 hf_model_name=hf_model_args.hf_model_name,
                 hf_task=hf_model_args.hf_task,
-                hf_token=hf_model_args.hf_token,
+                hf_token=(
+                    # when using inlined deployment spec, we need to use QMARK_RESERVED_TOKEN
+                    # to avoid revealing the token while calling the SYSTEM$DEPLOY_MODEL function
+                    # noop if using file-based deployment spec or token is not provided
+                    service_sql.QMARK_RESERVED_TOKEN
+                    if hf_model_args.hf_token and self._use_inlined_deployment_spec
+                    else hf_model_args.hf_token
+                ),
                 hf_tokenizer=hf_model_args.hf_tokenizer,
                 hf_revision=hf_model_args.hf_revision,
                 hf_trust_remote_code=hf_model_args.hf_trust_remote_code,
@@ -320,20 +328,31 @@ class ServiceOperator:
                 model_deployment_spec.ModelDeploymentSpec.DEPLOY_SPEC_FILE_REL_PATH if self._workspace else None
             ),
             model_deployment_spec_yaml_str=None if self._workspace else spec_yaml_str_or_path,
+            query_params=(
+                # when using inlined deployment spec, we need to add the token to the query params
+                # to avoid revealing the token while calling the SYSTEM$DEPLOY_MODEL function
+                # noop if using file-based deployment spec or token is not provided
+                [hf_model_args.hf_token]
+                if (self._use_inlined_deployment_spec and hf_model_args and hf_model_args.hf_token)
+                else []
+            ),
             statement_params=statement_params,
         )
 
-        # stream service logs in a thread
-        model_build_service_name = sql_identifier.SqlIdentifier(
-            self._get_service_id_from_deployment_step(query_id, DeploymentStep.MODEL_BUILD)
-        )
-        model_build_service = ServiceLogInfo(
-            database_name=service_database_name,
-            schema_name=service_schema_name,
-            service_name=model_build_service_name,
-            deployment_step=DeploymentStep.MODEL_BUILD,
-            log_color=service_logger.LogColor.GREEN,
-        )
+        model_build_service: Optional[ServiceLogInfo] = None
+        if is_enable_image_build:
+            # stream service logs in a thread
+            model_build_service_name = sql_identifier.SqlIdentifier(
+                self._get_service_id_from_deployment_step(query_id, DeploymentStep.MODEL_BUILD)
+            )
+            model_build_service = ServiceLogInfo(
+                database_name=service_database_name,
+                schema_name=service_schema_name,
+                service_name=model_build_service_name,
+                deployment_step=DeploymentStep.MODEL_BUILD,
+                log_color=service_logger.LogColor.GREEN,
+            )
+
         model_inference_service = ServiceLogInfo(
             database_name=service_database_name,
             schema_name=service_schema_name,
@@ -375,7 +394,7 @@ class ServiceOperator:
                 progress_status.increment()
 
                 # Poll for model build to start if not using existing service
-                if not model_inference_service_exists:
+                if not model_inference_service_exists and model_build_service:
                     self._wait_for_service_status(
                         model_build_service_name,
                         service_sql.ServiceStatus.RUNNING,
@@ -390,7 +409,7 @@ class ServiceOperator:
                 progress_status.increment()
 
                 # Poll for model build completion
-                if not model_inference_service_exists:
+                if not model_inference_service_exists and model_build_service:
                     self._wait_for_service_status(
                         model_build_service_name,
                         service_sql.ServiceStatus.DONE,
@@ -454,7 +473,7 @@ class ServiceOperator:
         self,
         async_job: snowpark.AsyncJob,
         model_logger_service: Optional[ServiceLogInfo],
-        model_build_service: ServiceLogInfo,
+        model_build_service: Optional[ServiceLogInfo],
         model_inference_service: ServiceLogInfo,
         model_inference_service_exists: bool,
         force_rebuild: bool,
@@ -483,7 +502,7 @@ class ServiceOperator:
         self,
         force_rebuild: bool,
         service_log_meta: ServiceLogMetadata,
-        model_build_service: ServiceLogInfo,
+        model_build_service: Optional[ServiceLogInfo],
         model_inference_service: ServiceLogInfo,
         operation_id: str,
         statement_params: Optional[dict[str, Any]] = None,
@@ -599,13 +618,24 @@ class ServiceOperator:
             # check if model logger service is done
             # and transition the service log metadata to the model image build service
             if service.deployment_step == DeploymentStep.MODEL_LOGGING:
-                service_log_meta.transition_service_log_metadata(
-                    model_build_service,
-                    f"Model Logger service {service.display_service_name} complete.",
-                    is_model_build_service_done=False,
-                    is_model_logger_service_done=service_log_meta.is_model_logger_service_done,
-                    operation_id=operation_id,
-                )
+                if model_build_service:
+                    # building the inference image, transition to the model build service
+                    service_log_meta.transition_service_log_metadata(
+                        model_build_service,
+                        f"Model Logger service {service.display_service_name} complete.",
+                        is_model_build_service_done=False,
+                        is_model_logger_service_done=service_log_meta.is_model_logger_service_done,
+                        operation_id=operation_id,
+                    )
+                else:
+                    # no model build service, transition to the model inference service
+                    service_log_meta.transition_service_log_metadata(
+                        model_inference_service,
+                        f"Model Logger service {service.display_service_name} complete.",
+                        is_model_build_service_done=True,
+                        is_model_logger_service_done=service_log_meta.is_model_logger_service_done,
+                        operation_id=operation_id,
+                    )
             # check if model build service is done
             # and transition the service log metadata to the model inference service
             elif service.deployment_step == DeploymentStep.MODEL_BUILD:
@@ -616,6 +646,8 @@ class ServiceOperator:
                     is_model_logger_service_done=service_log_meta.is_model_logger_service_done,
                     operation_id=operation_id,
                 )
+            elif service.deployment_step == DeploymentStep.MODEL_INFERENCE:
+                module_logger.info(f"Inference service {service.display_service_name} is deployed.")
             else:
                 module_logger.warning(f"Service {service.display_service_name} is done, but not transitioning.")
 
@@ -623,7 +655,7 @@ class ServiceOperator:
         self,
         async_job: snowpark.AsyncJob,
         model_logger_service: Optional[ServiceLogInfo],
-        model_build_service: ServiceLogInfo,
+        model_build_service: Optional[ServiceLogInfo],
         model_inference_service: ServiceLogInfo,
         model_inference_service_exists: bool,
         force_rebuild: bool,
@@ -632,14 +664,23 @@ class ServiceOperator:
     ) -> None:
         """Stream service logs while the async job is running."""
 
-        model_build_service_logger = service_logger.get_logger(  # BuildJobName
-            model_build_service.display_service_name,
-            model_build_service.log_color,
-            operation_id=operation_id,
-        )
-        if model_logger_service:
-            model_logger_service_logger = service_logger.get_logger(  # ModelLoggerName
-                model_logger_service.display_service_name,
+        if model_build_service:
+            model_build_service_logger = service_logger.get_logger(
+                model_build_service.display_service_name,  # BuildJobName
+                model_build_service.log_color,
+                operation_id=operation_id,
+            )
+            service_log_meta = ServiceLogMetadata(
+                service_logger=model_build_service_logger,
+                service=model_build_service,
+                service_status=None,
+                is_model_build_service_done=False,
+                is_model_logger_service_done=True,
+                log_offset=0,
+            )
+        elif model_logger_service:
+            model_logger_service_logger = service_logger.get_logger(
+                model_logger_service.display_service_name,  # ModelLoggerName
                 model_logger_service.log_color,
                 operation_id=operation_id,
             )
@@ -653,12 +694,17 @@ class ServiceOperator:
                 log_offset=0,
             )
         else:
+            model_inference_service_logger = service_logger.get_logger(
+                model_inference_service.display_service_name,  # ModelInferenceName
+                model_inference_service.log_color,
+                operation_id=operation_id,
+            )
             service_log_meta = ServiceLogMetadata(
-                service_logger=model_build_service_logger,
-                service=model_build_service,
+                service_logger=model_inference_service_logger,
+                service=model_inference_service,
                 service_status=None,
                 is_model_build_service_done=False,
-                is_model_logger_service_done=True,
+                is_model_logger_service_done=False,
                 log_offset=0,
             )
 
